@@ -5,9 +5,12 @@ from pydantic import BaseModel
 from pydantic import Field
 
 from .activity import Activity
+from .genre import Genre
+from .publisher import Publisher
 from .rating_list import RatingList
 from .score_list import ScoreList
 from .status_list import StatusList
+from .studio import Studio
 from .type_list import TypeList
 
 
@@ -20,7 +23,7 @@ class Stats(BaseModel):
     ratings: Optional[RatingList]
     has_anime: Optional[bool] = Field(alias='has_anime?')
     has_manga: Optional[bool] = Field(alias='has_manga?')
-    genres: Optional[List[str]]
-    studios: Optional[List[str]]
-    publishers: Optional[List[str]]
+    genres: Optional[List[Genre]]
+    studios: Optional[List[Studio]]
+    publishers: Optional[List[Publisher]]
     activity: Optional[Union[List[Activity], Dict]]
