@@ -7,11 +7,11 @@ from pydantic import BaseModel
 
 class Style(BaseModel):
     """Represents style entity."""
-    id: int
-    owner_id: int
-    owner_type: str
+    id: Optional[int]
+    owner_id: Optional[int]
+    owner_type: Optional[str]
     name: str
     css: str
     compiled_css: Optional[str]
-    created_at: datetime
-    updated_at: datetime
+    created_at: Optional[datetime]
+    updated_at: Optional[datetime]
